@@ -383,7 +383,7 @@ class ReadFromImageFile(Reader):
         path = expression_to_string_value(self.expression, self.interpreter, row)
         path_to_file = os.path.join(path_to_image, path)
         # img = plt.imread(path_to_file)
-        img = np.asarray(Image.open(path_to_file))
+        img = np.array(Image.open(path_to_file))
         if len(img.shape) == 3 and img.shape[-1] == 4:
             img = img[..., :3]
         if self.return_image_size:
