@@ -12,22 +12,22 @@ from ..base.histo_dataset import HistoDataset
 
 def midog_classification_patches(
     root: str,  # '/data/ldap/histopathologic/original_read_only/MIDOG'
-    transformation=None,
-    pre_transformation=None,
+    transformation: O[U[Callable, Sequence[Callable]]] = None,
+    pre_transformation: O[U[Callable, Sequence[Callable]]] = None,
     subset: str = "all",
     splitting_seed: int = 69,
     splitting_trainings_percentage: float = 0.8,
-    scanner_to_use: U[int, list] = None,
-    seed: int = None,
-    patch_size: int = None,
+    scanner_to_use: O[U[int, list]] = None,
+    seed: O[int] = None,
+    patch_size: O[int] = None,
 ) -> HistoDataset:
     """
-    Creates the MIDOG dataset and returns it as type HistoDataset, which inherits from torch.utils.data.Dataset.
+    Creates the MIDOG classification dataset and returns it as type HistoDataset, which inherits from torch.utils.data.Dataset.
 
-    Data and further information can be found at TODO.
+    Data and further information can be found at the README.md of the git repository (TODO).
 
     Arguments:
-        root: Absolute path to the dataset files.
+        root: Absolute or relative path to the dataset files.
         transformation: A callable or a list of callable transformations.
         pre_transformation: A callable or a list of
                        callable transformations. "pre_transformation"
@@ -37,14 +37,34 @@ def midog_classification_patches(
         subset: Which part of the dataset should be used.
                 One of {"train", "validation", "test", "all"}
         splitting_seed: Seed used for splitting the data set
-        splitting_trainings_percentage: Percentage how to split data
-        scanner_to_use: TODO
+        splitting_trainings_percentage: Specifies what percentage of the data
+                        is used for training. It must be a number between 0 and 1.
+                        This parameter also determines how much data is used for
+                        validation and testing: 1-{this-value}/2.
+        scanner_to_use: The midog classification dataset includes three scanners.
+                        This is a list or a integer that describes which scanner
+                        is used. Allowed values are 0,1 or 2.
         seed:   The seed that is used for the "pre_transformation" and the
                 "transformation". If the seed is set, the "pre_transformation"
                 will always use the same seed for a data row. If the seed is
                 set, the "transformation" will use always the same seed
-                depending on the call position.
-        patch_size: TODO
+                depending on the call position. For example:
+                    Call-Index,     Seed f.              Seed f.
+                                pre_transformation,  transformation
+                        0     ,     100           ,    124
+                        1     ,     100           ,    512
+                        2     ,     100           ,    810
+                        3     ,     100           ,    612
+                    If we create the exact same dataset the transformation seeds
+                    will be the same:
+                    Call-Index,     Seed f.              Seed f.
+                                pre_transformation,  transformation
+                        0     ,     100           ,    124
+                        1     ,     100           ,    512
+                        2     ,     100           ,    810
+                        3     ,     100           ,    612
+        patch_size: The images get cropped from the original image. Here you can
+                decide which size arround the mitosis get cropped.
 
     Returns:
         HistoDataset:
@@ -118,13 +138,14 @@ def midog_classification_patches(
         root,
         df_manipulators=manipulators_to_use,
         data_readers=data_reader,
-        feature_readers=data_readers.ReadValueFromCSV(r"{category_id}", encoded_values=['1', '2']),
+        feature_readers=data_readers.ReadValueFromCSV(r"{category_id}", encoded_values=["1", "2"]),
         seed=seed,
         pre_transfs=pre_transformation,
         da_transfs=transformation,
     )
     return ds
 
+
 """ TODO: how the offline dataset was generated
 # MIDOG
 from histodata.datasets import midog
@@ -163,6 +184,8 @@ ds = midog.midog_classification_patches(path_midog,
                       )
 ds.save('/data/ldap/histopathologic/original_read_only/MIDOG2/test')
 """
+
+
 def midog_classification_patches_preprocessed(
     root: str,  # '/data/ldap/histopathologic/original_read_only/MIDOG2/'
     transformation: O[U[Callable, Sequence[Callable]]] = None,
@@ -176,8 +199,8 @@ def midog_classification_patches_preprocessed(
     Data and further information can be found at TODO
 
     Arguments:
-        root: absolute path to the dataset files.
-                transformation (Callable): A callable or a list of
+        root: absolute or relative path to the dataset files.
+        transformation (Callable): A callable or a list of
                        callable transformations.
         pre_transformation (Callable): A callable or a list of
                        callable transformations. "pre_transformation"
@@ -190,7 +213,21 @@ def midog_classification_patches_preprocessed(
                 "transformation". If the seed is set, the "pre_transformation"
                 will always use the same seed for a data row. If the seed is
                 set, the "transformation" will use always the same seed
-                depending on the call position.
+                depending on the call position. For example:
+                    Call-Index,     Seed f.              Seed f.
+                                pre_transformation,  transformation
+                        0     ,     100           ,    124
+                        1     ,     100           ,    512
+                        2     ,     100           ,    810
+                        3     ,     100           ,    612
+                    If we create the exact same dataset the transformation seeds
+                    will be the same:
+                    Call-Index,     Seed f.              Seed f.
+                                pre_transformation,  transformation
+                        0     ,     100           ,    124
+                        1     ,     100           ,    512
+                        2     ,     100           ,    810
+                        3     ,     100           ,    612
 
     Returns:
         HistoDataset:
@@ -204,17 +241,16 @@ def midog_classification_patches_preprocessed(
         path_to_dataset = os.path.join(root, "train")
     elif subset.startswith("val"):
         path_to_dataset = os.path.join(root, "valid")
-    elif subset.startswith("test"):
+    elif subset.startswith("te"):
         path_to_dataset = os.path.join(root, "test")
     else:
         raise NotImplementedError(
             'The parameter "subset" needs to be one of ["train", "valid", "test"].'
         )
 
-    path_to_csv = os.path.join(path_to_dataset, "features.csv")
     # create HistoDataset object and pass relevant attributes
     ds = HistoDataset(
-        df_creators.CreateDFFromCSV(path_to_csv),
+        df_creators.CreateDFFromCSV("features.csv"),
         path_to_dataset,
         data_readers="data/{id}.tiff",
         feature_readers=data_readers.ReadValueFromCSV(r"{feature}", encoded_values=["0", "1"]),
